@@ -3,12 +3,12 @@ proj_name <- "test_nmproject"
 proj_path <- file.path(tempdir(), proj_name)
 
 test_that("run and post", {
-  
+
   skip_if_not(rmarkdown::pandoc_available("1.12.3"))
-  
+
   currentwd <- getwd()
   if (file.exists(proj_path)) unlink(proj_path, recursive = TRUE, force = TRUE)
-  nm_create_analysis_project(proj_path)
+  with_temp_git_config(nm_create_analysis_project(proj_path))
   on.exit({
     setwd(currentwd)
     unlink(proj_path, recursive = TRUE, force = TRUE)
@@ -24,7 +24,7 @@ test_that("run and post", {
   file.rename("cache", ".cache")
 
   unlink(testfilesloc, recursive = TRUE)
-  
+
   ## end boiler plate
   ############################
 
@@ -32,7 +32,7 @@ test_that("run and post", {
 
   ## run all scripts
   overwrite_behaviour("skip")
-  
+
   res <- tryCatch(run_all_scripts(), error = function(e) {
     on.exit({
       dump.frames(to.file = TRUE)
@@ -258,7 +258,7 @@ test_that("run and post", {
   expect_true(length(ls_tempfiles(m1)) == 0)
 
   ## clean up tests
-  clean_run(m1) ## remove non-temp
+  clean_tempfiles(m1) ## remove non-temp
   wipe_run(m1) ## remove all
   expect_true(!file.exists(run_dir_path(m1)))
 
